@@ -1,19 +1,3 @@
-# -*- coding:utf-8; python-indent:2; indent-tabs-mode:nil -*-
-
-# Copyright 2013 Google Inc. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """Visitor(s) for walking ASTs."""
 
 # Because pytype takes too long:
@@ -33,8 +17,6 @@ from pytype.pytd import pytd_utils
 from pytype.pytd import pytd_visitors
 from pytype.pytd.parse import parser_constants  # pylint: disable=g-importing-member
 
-import six
-
 
 class ContainerError(Exception):
   pass
@@ -107,7 +89,7 @@ class FillInLocalPointers(Visitor):
         "Lookup" function).
       fallback: A symbol table to be tried if lookup otherwise fails.
     """
-    super(FillInLocalPointers, self).__init__()
+    super().__init__()
     if fallback is not None:
       lookup_map["*"] = fallback
     self._lookup_map = lookup_map
@@ -187,7 +169,7 @@ class DefaceUnresolved(RemoveTypeParametersFromGenericAny):
       do_not_log_prefix: If given, don't log error messages for classes with
         this prefix.
     """
-    super(DefaceUnresolved, self).__init__()
+    super().__init__()
     self._lookup_list = lookup_list
     self._do_not_log_prefix = do_not_log_prefix
 
@@ -295,7 +277,7 @@ class VerifyLookup(Visitor):
   """Utility class for testing visitors.LookupClasses."""
 
   def __init__(self, ignore_late_types=False):
-    super(VerifyLookup, self).__init__()
+    super().__init__()
     self.ignore_late_types = ignore_late_types
 
   def EnterLateType(self, node):
@@ -320,7 +302,7 @@ class LookupBuiltins(Visitor):
       builtins: The builtins module.
       full_names: Whether to use fully qualified names for lookup.
     """
-    super(LookupBuiltins, self).__init__()
+    super().__init__()
     self._builtins = builtins
     self._full_names = full_names
 
@@ -383,7 +365,7 @@ class LookupExternalTypes(RemoveTypeParametersFromGenericAny):
         names. If the source contains "import X as Y", module_alias_map should
         contain an entry mapping "Y": "X".
     """
-    super(LookupExternalTypes, self).__init__()
+    super().__init__()
     self._module_map = module_map
     self._module_alias_map = module_alias_map or {}
     self.name = self_name
@@ -455,7 +437,8 @@ class LookupExternalTypes(RemoveTypeParametersFromGenericAny):
     if t.name in self._module_map:
       if self._alias_name and "." in self._alias_name:
         # Module aliases appear only in asts that use fully-qualified names.
-        return pytd.ToType(pytd.Module(name=t.name, module_name=t.name))
+        return pytd.ToType(
+            pytd.Module(name=self._alias_name, module_name=t.name))
       else:
         # We have a class with the same name as a module.
         return t
@@ -474,10 +457,10 @@ class LookupExternalTypes(RemoveTypeParametersFromGenericAny):
         item = t  # VisitTypeDeclUnit will remove this unneeded item.
       else:
         item = self._LookupItemRecursive(module, module_name, name)
-    except KeyError:
+    except KeyError as e:
       item = self._ResolveUsingGetattr(module_name, module)
       if item is None:
-        raise KeyError("No %s in module %s" % (name, module_name))
+        raise KeyError("No %s in module %s" % (name, module_name)) from e
     if not self._in_generic_type and isinstance(item, pytd.Alias):
       # If `item` contains type parameters and is not inside a GenericType, then
       # we replace the parameters with Any.
@@ -497,7 +480,7 @@ class LookupExternalTypes(RemoveTypeParametersFromGenericAny):
       try:
         t = MaybeSubstituteParameters(t.base_type, t.parameters) or t
       except ValueError as e:
-        raise KeyError(str(e))
+        raise KeyError(str(e)) from e
     return t
 
   def _ModulePrefix(self):
@@ -628,9 +611,9 @@ class LookupLocalTypes(RemoveTypeParametersFromGenericAny):
         # Happens for infer calling load_pytd.resolve_ast() for the final pyi
         try:
           item = self.unit.Lookup(node.name)
-        except KeyError:
+        except KeyError as e:
           raise SymbolLookupError("Couldn't find %s in %s" % (
-              node.name, self.unit.name))
+              node.name, self.unit.name)) from e
       return pytd.ToType(item, allow_constants=False)
     elif module_name == self.unit.name:
       return pytd.ToType(self.unit.Lookup(node.name), allow_constants=False)
@@ -655,7 +638,7 @@ class ReplaceTypes(Visitor):
       record: Optional. A set. If given, this records which entries in
         the map were used.
     """
-    super(ReplaceTypes, self).__init__()
+    super().__init__()
     self.mapping = mapping
     self.record = record
 
@@ -696,7 +679,7 @@ class ReplaceTypeParameters(Visitor):
   """Visitor for replacing type parameters with actual types."""
 
   def __init__(self, mapping):
-    super(ReplaceTypeParameters, self).__init__()
+    super().__init__()
     self.mapping = mapping
 
   def VisitTypeParameter(self, p):
@@ -727,7 +710,7 @@ class AdjustSelf(Visitor):
   """
 
   def __init__(self, force=False):
-    super(AdjustSelf, self).__init__()
+    super().__init__()
     self.class_types = []  # allow nested classes
     self.force = force
 
@@ -776,7 +759,7 @@ class RemoveUnknownClasses(Visitor):
   """
 
   def __init__(self):
-    super(RemoveUnknownClasses, self).__init__()
+    super().__init__()
     self.parameter = None
 
   def EnterParameter(self, p):
@@ -807,7 +790,7 @@ class _CountUnknowns(Visitor):
   """Visitor for counting how often given unknowns occur in a type."""
 
   def __init__(self):
-    super(_CountUnknowns, self).__init__()
+    super().__init__()
     self.counter = collections.Counter()
     self.position = {}
 
@@ -856,7 +839,7 @@ class CreateTypeParametersForSignatures(Visitor):
   PREFIX = "_T"  # Prefix for new type params
 
   def __init__(self):
-    super(CreateTypeParametersForSignatures, self).__init__()
+    super().__init__()
     self.parameter = None
     self.class_name = None
     self.function_name = None
@@ -885,7 +868,7 @@ class CreateTypeParametersForSignatures(Visitor):
       (self: X[, ...]) -> X
     so that we can replace X with a bounded TypeVar. This heuristic
     isn't perfect; for example, in this naive copy method:
-      class X(object):
+      class X:
         def copy(self):
           return X()
     we should have left X alone. But it prevents a number of false
@@ -969,11 +952,11 @@ class VerifyVisitor(Visitor):
   """Visitor for verifying pytd ASTs. For tests."""
 
   def __init__(self):
-    super(VerifyVisitor, self).__init__()
+    super().__init__()
     self._valid_param_name = re.compile(r"[a-zA-Z_]\w*$")
 
   def Enter(self, node):
-    super(VerifyVisitor, self).Enter(node)
+    super().Enter(node)
     node.Validate()
 
   def _AssertNoDuplicates(self, node, attrs):
@@ -1031,7 +1014,7 @@ class RemoveFunctionsAndClasses(Visitor):
   """Visitor for removing unwanted functions or classes."""
 
   def __init__(self, names):
-    super(RemoveFunctionsAndClasses, self).__init__()
+    super().__init__()
     self.names = names
 
   def VisitTypeDeclUnit(self, node):
@@ -1067,7 +1050,7 @@ class AddNamePrefix(Visitor):
   """
 
   def __init__(self):
-    super(AddNamePrefix, self).__init__()
+    super().__init__()
     self.cls_stack = []
     self.classes = None
     self.prefix = None
@@ -1158,7 +1141,7 @@ class CollectDependencies(Visitor):
   """
 
   def __init__(self):
-    super(CollectDependencies, self).__init__()
+    super().__init__()
     self.dependencies = {}
     self.late_dependencies = {}
 
@@ -1266,7 +1249,7 @@ class AdjustTypeParameters(Visitor):
   """
 
   def __init__(self):
-    super(AdjustTypeParameters, self).__init__()
+    super().__init__()
     self.class_typeparams = set()
     self.function_typeparams = None
     self.class_template = []
@@ -1342,9 +1325,9 @@ class AdjustTypeParameters(Visitor):
 
     try:
       template = mro.MergeSequences(templates)
-    except ValueError:
+    except ValueError as e:
       raise ContainerError(
-          "Illegal type parameter order in class %s" % node.name)
+          "Illegal type parameter order in class %s" % node.name) from e
 
     self.class_template.append(template)
 
@@ -1628,7 +1611,7 @@ class ExpandCompatibleBuiltins(Visitor):
   """
 
   def __init__(self, builtins):
-    super(ExpandCompatibleBuiltins, self).__init__()
+    super().__init__()
     self.in_parameter = False
     self.in_type_parameter = False
     self.replacements = self._BuildReplacementMap(builtins)
@@ -1656,7 +1639,7 @@ class ExpandCompatibleBuiltins(Visitor):
         # want it in our union
         rmap[prefix + name].append(pytd.ClassType(full_name, t))
 
-    return {k: pytd.UnionType(tuple(v)) for k, v in six.iteritems(rmap)}
+    return {k: pytd.UnionType(tuple(v)) for k, v in rmap.items()}
 
   def EnterParameter(self, _):
     assert not self.in_parameter
@@ -1700,7 +1683,7 @@ class ReplaceModulesWithAny(RemoveTypeParametersFromGenericAny):
   """Replace all references to modules in a list with AnythingType."""
 
   def __init__(self, module_list):
-    super(ReplaceModulesWithAny, self).__init__()
+    super().__init__()
     assert isinstance(module_list, list)
     self._any_modules = module_list
 
@@ -1734,7 +1717,7 @@ class ClassTypeToLateType(Visitor):
         convert builtin types to late types. (And, more generally, types of
         modules that are always loaded by pytype don't need to be late types)
     """
-    super(ClassTypeToLateType, self).__init__()
+    super().__init__()
     self._ignore = ignore
 
   def VisitClassType(self, n):
